| PLL | R Documentation |
Generic function for extracting th predictive partial log-likelihood from a fitted survival model.
PLL(object, newdata, newtime, newstatus, ...)
object |
fitted model of class |
newdata |
|
newtime |
|
newstatus |
|
... |
additional arguments, for example complexity value, if necessary. |
The predictive partial log-likelihood measures the prediction performance of each model fitted in a boostrap sample, using the data not in this sample. Multiplying by (-2) leads to a deviance-like measure, which means that small values indicate good prediction performance.
peperr requires function PLL.class in case of survival response, for each model fit of class class.
Available methods include PLL.CoxBoost, PLL.coxph, PLL.penfit, PLL.coxnet, PLL.grpsurv, PLL.ncvsurv, PLL.mboost_coxph, and PLL.SGL_cox.
Numeric predictive partial log-likelihood returned by the method implementation.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.