| PLL.CoxBoost | R Documentation |
Extracts the predictive partial log-likelihood from a CoxBoost model fit.
## S3 method for class 'CoxBoost'
PLL(object, newdata, newtime, newstatus, complexity, ...)
object |
fitted model of class |
newdata |
|
newtime |
|
newstatus |
|
complexity |
complexity, either one value, which is the number of boosting steps, or a list containing |
... |
additional arguments passed to |
Used by function peperr, if function fit.CoxBoost is used for model fit.
Since CoxBoost is only suggested by peperr, install it before calling this function.
Numeric predictive partial log-likelihood returned by predict.CoxBoost.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.