| fit.SGL.cox | R Documentation |
Wrappers for Cox models fitted with SGL.
fit.SGL.cox(response, x, cplx, index, ...)
complexity.cvSGL.cox(response, x, full.data, index, ...)
## S3 method for class 'SGL_cox'
predictProb(object, response, x, times, complexity = NULL, ...)
## S3 method for class 'SGL_cox'
PLL(object, newdata, newtime, newstatus, complexity = NULL, ...)
response |
survival response as a |
x |
covariate matrix. |
cplx |
selected |
index |
group membership vector for the columns of |
full.data |
full data frame, accepted for the |
object |
a fitted |
times |
evaluation times for survival probabilities. |
complexity |
selected |
newdata |
new covariate matrix. |
newtime |
vector of follow-up times. |
newstatus |
vector of event indicators. |
... |
additional arguments passed to |
The SGL predictor returns relative risks. The peperr wrapper reconstructs survival probabilities from those risks with a Breslow baseline estimated on the stored training data.
Fitted SGL_cox objects, selected lambda values, survival-probability matrices, and numeric predictive partial log-likelihood values, respectively.
peperr, SGL, cvSGL
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.