fit.CoxBoost: Interface function for fitting a CoxBoost model

View source: R/fit.CoxBoost.R

fit.CoxBoostR Documentation

Interface function for fitting a CoxBoost model

Description

Interface for fitting survival models by CoxBoost, conforming to the requirements for argument fit.fun in peperr call.

Usage

fit.CoxBoost(response, x, cplx, ...)

Arguments

response

a survival object (with Surv(time, status)).

x

n*p matrix of covariates.

cplx

number of boosting steps, or a list containing at least stepno and optionally further CoxBoost tuning arguments.

...

additional arguments passed to CoxBoost call.

Details

Function is basically a wrapper around CoxBoost of package CoxBoost. A Cox proportional hazards model is fitted by componentwise likelihood based boosting, especially suited for models with many covariates and few observations.

Since CoxBoost is only suggested by peperr, install it before calling this function.

Value

CoxBoost object

See Also

peperr, CoxBoost


peperr documentation built on March 25, 2026, 9:06 a.m.