fit.coxph: Interface function for fitting a Cox proportional hazards model
Description
Interface for fitting survival models by Cox proporional hazards model, conforming to the requirements for argument fit.fun in peperr call.
Usage
fit.coxph(response, x, cplx, ...)
Arguments
- response
a survival object (with Surv(time, status)).
- x
n*p matrix of covariates.
- cplx
not used.
- ...
additional arguments passed to coxph call.
Details
Function is basically a wrapper around coxph of package survival.