View source: R/predictProb.CoxBoost.R
| predictProb.CoxBoost | R Documentation |
Extracts predicted survival probabilities from a survival model fitted by CoxBoost, providing an interface as required by pmpec.
## S3 method for class 'CoxBoost'
predictProb(object, response, x, times, complexity, ...)
object |
a fitted model of class |
response |
survival object (with |
x |
|
times |
vector of evaluation time points. |
complexity |
complexity value, or a list containing |
... |
additional arguments passed to |
Since CoxBoost is only suggested by peperr, install it before calling this function.
Matrix with probabilities for each evaluation time point in times (columns) and each new observation (rows).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.