View source: R/complexity.LASSO.R
| complexity.cv.penalized | R Documentation |
Wrapper functions for choosing the penalized tuning parameter used by fit.penalized, fit.LASSO, and fit.fusedLASSO.
complexity.cv.penalized(response, x, full.data, ...)
complexity.LASSO(response, x, full.data, ...)
complexity.fusedLASSO(response, x, full.data, ...)
response |
response used for model fitting. Survival responses may be passed as a |
x |
|
full.data |
data frame containing the full data set. This argument is accepted to match the |
... |
additional arguments passed to |
complexity.cv.penalized profiles the cross-validated lambda1 values returned by profL1 and keeps the maximizer. complexity.LASSO is a compatibility alias. complexity.fusedLASSO performs the same search while forwarding fusedl = TRUE.
A scalar tuning value, typically the selected lambda1.
fit.penalized, fit.LASSO, fit.fusedLASSO, profL1
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.