Determines the optimal value for tuning parameter lambda for a regression model with lasso penalties via cross-validation. Conforming to the calling convention required by argument complexity in peperr call.
complexity.LASSO(response, x, full.data, ...)Scalar value giving the optimal value for lambda.
a survival object (Surv(time, status)).
n*p matrix of covariates.
data frame containing response and covariates of the full data set.
additional arguments passed to optL1 of package penalized call.
Function is basically a wrapper around optL1 of package penalized. Calling peperr, default arguments of optL1 can be changed by passing a named list containing these as argument args.complexity.
peperr, optL1