Interface for CoxBoost selection of the optimal number of boosting steps via cross-validation
complexity.mincv.CoxBoost.RdDetermines the number of boosting steps for a survival model fitted by CoxBoost via cross-validation, conforming to the calling convention required by argument complexity in peperr call.
Details
Function is basically a wrapper around cv.CoxBoost of package CoxBoost. A K-fold cross-validation (default K = 10) is performed to search the optimal number of boosting steps, per default in the interval [0, maxstepno]. Calling peperr, the default arguments of cv.CoxBoost can be changed by passing a named list containing these as argument args.complexity.
Since CoxBoost is only suggested by peperr, install it before calling this function.
See also
peperr, cv.CoxBoost