View source: R/complexity.mincv.CoxBoost.R
| complexity.mincv.CoxBoost | R Documentation |
Determines the number of boosting steps for a survival model fitted by CoxBoost via cross-validation, conforming to the calling convention required by argument complexity in peperr call.
complexity.mincv.CoxBoost(response, x, full.data, ...)
response |
a survival object ( |
x |
|
full.data |
data frame containing response and covariates of the full data set. |
... |
additional arguments passed to |
Function is basically a wrapper around cv.CoxBoost of package CoxBoost. A K-fold cross-validation (default K = 10) is performed to search the optimal number of boosting steps, per default in the interval [0, maxstepno]. Calling peperr, the default arguments of cv.CoxBoost can be changed by passing a named list containing these as argument args.complexity.
Since CoxBoost is only suggested by peperr, install it before calling this function.
Scalar value giving the optimal number of boosting steps.
peperr, cv.CoxBoost
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.