Interface function for fitting a CoxBoost model
fit.CoxBoost.RdInterface for fitting survival models by CoxBoost, conforming to the requirements for argument fit.fun in peperr call.
Details
Function is basically a wrapper around CoxBoost of package CoxBoost. A Cox proportional hazards model is fitted by componentwise likelihood based boosting, especially suited for models with many covariates and few observations.
Since CoxBoost is only suggested by peperr, install it before calling this function.
See also
peperr, CoxBoost