| fit.CoxBoost | R Documentation |
Interface for fitting survival models by CoxBoost, conforming to the requirements for argument fit.fun in peperr call.
fit.CoxBoost(response, x, cplx, ...)
response |
a survival object (with |
x |
|
cplx |
number of boosting steps, or a list containing at least |
... |
additional arguments passed to |
Function is basically a wrapper around CoxBoost of package CoxBoost. A Cox proportional hazards model is fitted by componentwise likelihood based boosting, especially suited for models with many covariates and few observations.
Since CoxBoost is only suggested by peperr, install it before calling this function.
CoxBoost object
peperr, CoxBoost
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.