| fit.penalized | R Documentation |
Interface functions for fitting penalized models in peperr. The generic wrapper is fit.penalized; fit.LASSO and fit.fusedLASSO are convenience aliases for plain and fused lasso fits.
fit.penalized(response, x, cplx, ...)
fit.LASSO(response, x, cplx, ...)
fit.fusedLASSO(response, x, cplx, ...)
response |
response. This can be a binary vector, a numeric response, a |
x |
|
cplx |
complexity value. For the penalized backend this is usually |
... |
additional arguments passed to |
fit.penalized is the general wrapper around penalized. For survival models it also stores the training design matrix and response so that predictProb.penfit and PLL.penfit can be used later by pmpec and peperr.
fit.LASSO simply calls fit.penalized. fit.fusedLASSO calls the same backend with fusedl = TRUE.
A fitted penfit object.
complexity.cv.penalized, predictProb.penfit, PLL.penfit, penalized
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.