Interface for fitting survival models with the lasso, conforming to the requirements of argument fit.fun in peperr call.
fit.LASSO(response, x, cplx, ...)response. Could be numeric vector for linear regression, Surv object for Cox regression or a binary vector for logistic regression.
n*p matrix of covariates.
LASSO penalty. lambda1 of penalized call.
additional arguments passed to penalized call.
penfit object
Function is basically a wrapper around function penalized of package penalized.
peperr, penalized