| fit.glmnet | R Documentation |
Wrappers that integrate glmnet Cox models into the peperr fit/complexity/prediction interface.
fit.glmnet(response, x, cplx, ...)
complexity.cv.glmnet(response, x, full.data, ...)
## S3 method for class 'coxnet'
predictProb(object, response, x, times, complexity = NULL, ...)
## S3 method for class 'coxnet'
PLL(object, newdata, newtime, newstatus, complexity = NULL, ...)
response |
survival response as a |
x |
covariate matrix. |
cplx |
selected |
full.data |
full data frame, accepted for the |
object |
a fitted |
times |
evaluation times for survival probabilities. |
complexity |
selected |
newdata |
new covariate matrix. |
newtime |
vector of follow-up times. |
newstatus |
vector of event indicators. |
... |
additional arguments passed to |
The backend stores the training design matrix and survival outcome on the fitted object so that the survfit.coxnet method can be reused later when pmpec calls predictProb.
fit.glmnet returns a fitted coxnet object. complexity.cv.glmnet returns a scalar lambda. predictProb.coxnet returns an n * length(times) survival-probability matrix. PLL.coxnet returns a numeric predictive partial log-likelihood.
peperr, predictProb, PLL, glmnet, cv.glmnet
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.