| fit.mboost.coxph | R Documentation |
Wrappers for Cox boosting models fitted with mboost.
fit.mboost.coxph(response, x, cplx, ...)
complexity.cvrisk.mboost(response, x, full.data, max.mstop = 100L, folds = NULL, ...)
## S3 method for class 'mboost_coxph'
predictProb(object, response, x, times, complexity = NULL, ...)
## S3 method for class 'mboost_coxph'
PLL(object, newdata, newtime, newstatus, complexity = NULL, ...)
response |
survival response as a |
x |
covariate matrix. |
cplx |
selected stopping iteration |
full.data |
full data frame, accepted for the |
max.mstop |
maximum number of boosting iterations considered during cross-validation. |
folds |
optional mboost fold specification passed to |
object |
a fitted |
times |
evaluation times for survival probabilities. |
complexity |
selected stopping iteration. |
newdata |
new covariate matrix. |
newtime |
vector of follow-up times. |
newstatus |
vector of event indicators. |
... |
additional arguments passed to |
If mboost provides native survival-curve predictions for the fitted model, predictProb.mboost_coxph uses them. Otherwise it falls back to a Breslow baseline estimated from the stored training data and linear predictors.
Fitted mboost_coxph objects, selected stopping iterations, survival-probability matrices, and numeric predictive partial log-likelihood values, respectively.
peperr, glmboost, cvrisk
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.