Predicted survival probabilities for penalized Cox models
predictProb.penfit.RdExtracts survival probabilities from a penfit survival model for use in pmpec.
Usage
# S3 method for class 'penfit'
predictProb(object, response, x, times, complexity = NULL, ...)Arguments
- object
a fitted
penfitobject.- response
survival response, passed for consistency with the
predictProbinterface.- x
new covariate matrix.
- times
evaluation times.
- complexity
unused for fitted
penfitobjects; included for interface compatibility.- ...
additional arguments passed to the penalized prediction method.
Value
Matrix of survival probabilities with one row per observation and one column per evaluation time.