View source: R/predictProb.penfit.R
| predictProb.penfit | R Documentation |
Extracts survival probabilities from a penfit survival model for use in pmpec.
## S3 method for class 'penfit'
predictProb(object, response, x, times, complexity = NULL, ...)
object |
a fitted |
response |
survival response, passed for consistency with the |
x |
new covariate matrix. |
times |
evaluation times. |
complexity |
unused for fitted |
... |
additional arguments passed to the penalized prediction method. |
Matrix of survival probabilities with one row per observation and one column per evaluation time.
predictProb, fit.penalized, PLL.penfit
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.